@@ -51,43 +51,18 @@ enum {UI, XML, SRVR};
 
 enum {BINARY, STRING};
 
-enum {
-	NONE,
-
-	FT100D, FT450,  FT450D, FT747,    FT767,  FT817,
-	FT847,  FT857D, FT890,    FT897D, FT920,
-	FT950,  FT990,  FT1000MP, FT2000, FTdx1200, FTdx3000,
-	FT5000,
-
-	IC703, IC706MKIIG, IC718, IC728, IC735, IC746,
-	IC746PRO, IC756, IC756PRO, IC756PRO2, IC756PRO3,
-	IC7000, IC7100, IC7200, IC7410, IC7600, IC7700,
-	IC9100, IC910H,
-
-	K2, K3, KX3,
-
-	PCR1000,
-
-	RAY152,
-
-	TS140, TS450S, TS480HX, TS480SAT, TS570, TS590S, TS870S, TS990, TS2000,
-
-	TT516, TT535, TT538, TT550, TT563, TT566, TT588, TT599, // 48
-
-	LAST_RIG
-};
-
 class rigbase {
+#define WVALS_LIMIT -1
 public:
-	const char * name_;
+	string name_;
 	const char ** modes_;
 	const char ** bandwidths_;
-	const char ** dsp_lo;
-	const char *  lo_tooltip;
-	const char *  lo_label;
-	const char ** dsp_hi;
-	const char *  hi_tooltip;
-	const char *  hi_label;
+	const char ** dsp_SL;
+	const char *  SL_tooltip;
+	const char *  SL_label;
+	const char ** dsp_SH;
+	const char *  SH_tooltip;
+	const char *  SH_label;
 	const int  * bw_vals_;
 
 	GUI *widgets;
@@ -146,6 +121,7 @@ public:
 
 	bool has_xcvr_auto_on_off;
 	bool has_a2b;
+	bool has_b2a;
 	bool has_vfo_adj;
 	bool has_rit;
 	bool has_xit;
@@ -176,6 +152,7 @@ public:
 	bool has_split;
 	bool has_split_AB;
 	bool has_data_port;
+	bool has_getvfoAorB;
 
 	bool has_extras;
 	bool has_nb_level;
@@ -253,6 +230,8 @@ public:
 	virtual void selectA(){}
 	virtual void selectB(){}
 	virtual void A2B(){}
+	virtual void B2A(){}
+	virtual int  get_vfoAorB(){return 0;}
 
 	virtual void swapAB(){}
 
@@ -263,8 +242,8 @@ public:
 	virtual int  adjust_bandwidth(int m) {return 0;}
 	virtual int  def_bandwidth(int m) {return 0;}
 	virtual const char **bwtable(int m) {return bandwidths_;}
-	virtual const char **lotable(int m) {return dsp_lo;}
-	virtual const char **hitable(int m) {return dsp_hi;}
+	virtual const char **lotable(int m) {return NULL;}
+	virtual const char **hitable(int m) {return NULL;}
 
 	virtual bool can_split() { return false;}
 	virtual void set_split(bool val) {split = val;}
@@ -455,7 +434,6 @@ public:
 };
 
 extern rigbase *rigs[];
-extern int rig_nbr;
 
 extern const char *szNORIG;
 extern const char *szNOMODES[];
