@@ -31,13 +31,17 @@
 #include "FT847.h"
 #include "FT857D.h"
 #include "FT890.h"
+#include "FT900.h"
 #include "FT920.h"
 #include "FT950.h"
 #include "FT990.h"
+#include "FT990a.h"
+#include "FT991.h"
 #include "FT1000MP.h"
 #include "FT2000.h"
 #include "FTdx1200.h"
 #include "FTdx3000.h"
+#include "FTdx9000.h"
 #include "FT5000.h"
 #include "ICbase.h"
 #include "IC703.h"
@@ -56,6 +60,7 @@
 #include "IC7200.h"
 #include "IC7600.h"
 #include "IC7700.h"
+#include "IC7800.h"
 #include "IC9100.h"
 #include "K2.h"
 #include "K3.h"
@@ -68,6 +73,7 @@
 #include "TS480SAT.h"
 #include "TS570.h"
 #include "TS590S.h"
+#include "TS590SG.h"
 #include "TS870S.h"		// wbx
 #include "TS990.h"		// G0HIX
 #include "TS2000.h"
@@ -91,54 +97,60 @@ extern RIG_FT847		rig_FT847;		// 7
 extern RIG_FT857D		rig_FT857D;		// 8
 extern RIG_FT890		rig_FT890;		// 9
 extern RIG_FT897D		rig_FT897D;		// 10
-extern RIG_FT920		rig_FT920;		// 11
-extern RIG_FT950		rig_FT950;		// 12
-extern RIG_FT990		rig_FT990;		// 13
-extern RIG_FT1000MP	rig_FT1000MP;	// 14
-extern RIG_FT2000		rig_FT2000;		// 15
-extern RIG_FTdx1200	rig_FTdx1200;	// 16
-extern RIG_FTdx3000	rig_FTdx3000;	// 17
-extern RIG_FT5000		rig_FT5000;		// 18
-extern RIG_IC703		rig_IC703;		// 19
-extern RIG_IC706MKIIG	rig_IC706MKIIG;	// 20
-extern RIG_IC718		rig_IC718;		// 21
-extern RIG_IC728		rig_IC728;		// 22
-extern RIG_IC735		rig_IC735;		// 23
-extern RIG_IC746		rig_IC746;		// 24
-extern RIG_IC746PRO	rig_IC746PRO;	// 25
-extern RIG_IC756		rig_IC756;		// 26
-extern RIG_IC756PRO	rig_IC756PRO;	// 27
-extern RIG_IC756PRO2	rig_IC756PRO2;	// 28
-extern RIG_IC756PRO3	rig_IC756PRO3;	// 29
-extern RIG_IC7000		rig_IC7000;		// 30
-extern RIG_IC7100		rig_IC7100;		// 31
-extern RIG_IC7200		rig_IC7200;		// 32
-extern RIG_IC7410		rig_IC7410;		// 33
-extern RIG_IC7600		rig_IC7600;		// 34
-extern RIG_IC7700		rig_IC7700;		// 35
-extern RIG_IC9100		rig_IC9100;		// 36
-extern RIG_IC910H		rig_IC910H;		// 37
-extern RIG_K2			rig_K2;			// 38
-extern RIG_K3			rig_K3;			// 39
-extern RIG_KX3			rig_KX3;		// 40
-extern RIG_PCR1000		rig_PCR1000;	// 41
-extern RIG_RAY152		rig_RAY152;		// 42
-extern RIG_TS140		rig_TS140;		// 43
-extern RIG_TS450S		rig_TS450S;		// 44
-extern RIG_TS480HX		rig_TS480HX;	// 45
-extern RIG_TS480SAT	rig_TS480SAT;	// 46
-extern RIG_TS570		rig_TS570;		// 47
-extern RIG_TS590S		rig_TS590S;		// 48
-extern RIG_TS870S		rig_TS780S;		// 49 wbx
-extern RIG_TS990		rig_TS990;		// 50 G0HIX
-extern RIG_TS2000		rig_TS2000;		// 51
-extern RIG_TT516		rig_TT516;		// 52
-extern RIG_TT535		rig_TT535;		// 53
-extern RIG_TT538		rig_TT538;		// 54
-extern RIG_TT550		rig_TT550;		// 55
-extern RIG_TT563		rig_TT563;		// 56
-extern RIG_TT566		rig_TT566;		// 57
-extern RIG_TT588		rig_TT588;		// 58
-extern RIG_TT599		rig_TT599;		// 59
+extern RIG_FT900		rig_FT900;		// 11
+extern RIG_FT920		rig_FT920;		// 12
+extern RIG_FT950		rig_FT950;		// 13
+extern RIG_FT990		rig_FT990;		// 14
+extern RIG_FT990A		rig_FT990A;		// 15
+extern RIG_FT991		rig_FT991;		// 16
+extern RIG_FT1000MP     rig_FT1000MP;	// 17
+extern RIG_FT2000		rig_FT2000;		// 18
+extern RIG_FTdx1200		rig_FTdx1200;	// 19
+extern RIG_FTdx3000		rig_FTdx3000;	// 20
+extern RIG_FT5000		rig_FT5000;		// 21
+extern RIG_FTdx9000		rig_FTdx9000;	// 22
+extern RIG_IC703		rig_IC703;		// 23
+extern RIG_IC706MKIIG	rig_IC706MKIIG;	// 24
+extern RIG_IC718		rig_IC718;		// 25
+extern RIG_IC728		rig_IC728;		// 26
+extern RIG_IC735		rig_IC735;		// 27
+extern RIG_IC746		rig_IC746;		// 28
+extern RIG_IC746PRO     rig_IC746PRO;	// 29
+extern RIG_IC756		rig_IC756;		// 30
+extern RIG_IC756PRO     rig_IC756PRO;	// 31
+extern RIG_IC756PRO2	rig_IC756PRO2;	// 32
+extern RIG_IC756PRO3	rig_IC756PRO3;	// 33
+extern RIG_IC7000		rig_IC7000;		// 34
+extern RIG_IC7100		rig_IC7100;		// 35
+extern RIG_IC7200		rig_IC7200;		// 36
+extern RIG_IC7410		rig_IC7410;		// 37
+extern RIG_IC7600		rig_IC7600;		// 38
+extern RIG_IC7700		rig_IC7700;		// 39
+extern RIG_IC7800		rig_IC7800;		// 40
+extern RIG_IC9100		rig_IC9100;		// 41
+extern RIG_IC910H		rig_IC910H;		// 42
+extern RIG_K2			rig_K2;			// 43
+extern RIG_K3			rig_K3;			// 44
+extern RIG_KX3			rig_KX3;		// 45
+extern RIG_PCR1000		rig_PCR1000;	// 46
+extern RIG_RAY152		rig_RAY152;		// 47
+extern RIG_TS140		rig_TS140;		// 48
+extern RIG_TS450S		rig_TS450S;		// 49
+extern RIG_TS480HX		rig_TS480HX;	// 50
+extern RIG_TS480SAT	    rig_TS480SAT;	// 51
+extern RIG_TS570		rig_TS570;		// 52
+extern RIG_TS590S		rig_TS590S;		// 53
+extern RIG_TS590SG      rig_TS590SG;    // 54
+extern RIG_TS870S		rig_TS870S;		// 55 wbx
+extern RIG_TS990		rig_TS990;		// 56 G0HIX
+extern RIG_TS2000		rig_TS2000;		// 57
+extern RIG_TT516		rig_TT516;		// 58
+extern RIG_TT535		rig_TT535;		// 59
+extern RIG_TT538		rig_TT538;		// 60
+extern RIG_TT550		rig_TT550;		// 61
+extern RIG_TT563		rig_TT563;		// 62
+extern RIG_TT566		rig_TT566;		// 63
+extern RIG_TT588		rig_TT588;		// 64
+extern RIG_TT599		rig_TT599;		// 65
 
 #endif
