@@ -36,7 +36,6 @@ struct status {
 	int		mainH;
 	int		UIsize;
 	bool	UIchanged;
-	int		rig_nbr;
 	string	xcvr_serial_port;
 	int		comm_baudrate;
 	int		stopbits;
@@ -84,6 +83,7 @@ struct status {
 	int		poll_split;
 	int		poll_noise;
 	int		poll_nr;
+	int     	poll_vfoAorB;
 	int		poll_all;
 
 	int		iBW_A;
@@ -253,7 +253,7 @@ struct status {
 	Fl_Font	fontnbr;
 
 	bool	tooltips;
-	
+
 	string	ui_scheme;
 
 	string	server_port;
@@ -271,12 +271,15 @@ struct status {
 
 	bool	external_tuner;
 
+	bool	fldigi_is_server;
+
 	void saveLastState();
 	void loadLastState();
-	bool loadXcvrState(const char *);
+	bool loadXcvrState(string);
 	void UI_laststate();
 };
 
 extern status progStatus;
+extern string xcvr_name;
 
 #endif
