@@ -16,10 +16,11 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with the program; if not, write to the Free Software
-// Foundation, Inc.
-// 59 Temple Place, Suite 330
-// Boston, MA  02111-1307 USA
+// along with the program; if not, write to the
+//
+//  Free Software Foundation, Inc.
+//  51 Franklin Street, Fifth Floor
+//  Boston, MA  02110-1301 USA.
 //
 // ---------------------------------------------------------------------
 
@@ -44,3 +45,5 @@
 
 extern void start_server(int port = 12345);
 extern void exit_server();
+
+#endif
