@@ -38,14 +38,18 @@ RIG_FT847		rig_FT847;
 RIG_FT857D		rig_FT857D;
 RIG_FT890		rig_FT890;
 RIG_FT897D		rig_FT897D;
+RIG_FT900		rig_FT900;
 RIG_FT920		rig_FT920;
 RIG_FT950		rig_FT950;
 RIG_FT990		rig_FT990;
+RIG_FT990A		rig_FT990A;
+RIG_FT991		rig_FT991;
 RIG_FT1000MP	rig_FT1000MP;
 RIG_FT2000		rig_FT2000;
 RIG_FTdx1200	rig_FTdx1200;
 RIG_FTdx3000	rig_FTdx3000;
 RIG_FT5000		rig_FT5000;
+RIG_FTdx9000	rig_FTdx9000;
 
 RIG_IC703		rig_IC703;
 RIG_IC706MKIIG	rig_IC706MKIIG;
@@ -64,6 +68,7 @@ RIG_IC7410		rig_IC7410;
 RIG_IC7200		rig_IC7200;
 RIG_IC7600		rig_IC7600;
 RIG_IC7700		rig_IC7700;
+RIG_IC7800		rig_IC7800;
 RIG_IC9100		rig_IC9100;
 RIG_IC910H		rig_IC910H;
 
@@ -80,6 +85,7 @@ RIG_TS480HX		rig_TS480HX;
 RIG_TS480SAT	rig_TS480SAT;
 RIG_TS570		rig_TS570;
 RIG_TS590S		rig_TS590S;
+RIG_TS590SG     rig_TS590SG;
 RIG_TS870S		rig_TS870S;
 RIG_TS990		rig_TS990;
 RIG_TS2000		rig_TS2000;
@@ -105,55 +111,61 @@ rigbase *rigs[] = {
 	&rig_FT857D,	// 8
 	&rig_FT890,		// 9
 	&rig_FT897D,	// 10
-	&rig_FT920,		// 11
-	&rig_FT950,		// 12
-	&rig_FT990,		// 13
-	&rig_FT1000MP,	// 14
-	&rig_FT2000,	// 15
-	&rig_FTdx1200,	// 16
-	&rig_FTdx3000,	// 17
-	&rig_FT5000,	// 18
-	&rig_IC703,		// 19
-	&rig_IC706MKIIG,// 20
-	&rig_IC718,		// 21
-	&rig_IC728,		// 22
-	&rig_IC735,		// 23
-	&rig_IC746,		// 24
-	&rig_IC746PRO,	// 25
-	&rig_IC756,		// 26
-	&rig_IC756PRO,	// 27
-	&rig_IC756PRO2,	// 28
-	&rig_IC756PRO3,	// 29
-	&rig_IC7000,	// 30
-	&rig_IC7100,	// 31
-	&rig_IC7200,	// 32
-	&rig_IC7410,	// 33
-	&rig_IC7600,	// 34
-	&rig_IC7700,	// 35
-	&rig_IC9100,	// 36
-	&rig_IC910H,	// 37
-	&rig_K2,		// 38
-	&rig_K3,		// 39
-	&rig_KX3,		// 40
-	&rig_PCR1000,	// 41
-	&rig_RAY152,	// 42
-	&rig_TS140,		// 43
-	&rig_TS450S,	// 44
-	&rig_TS480HX,	// 45
-	&rig_TS480SAT,	// 46
-	&rig_TS570,		// 47
-	&rig_TS590S,	// 48
-	&rig_TS870S,	// 49 wbx
-	&rig_TS990,		// 50
-	&rig_TS2000,	// 51
-	&rig_TT516,		// 52
-	&rig_TT535,		// 53
-	&rig_TT538,		// 54
-	&rig_TT550,		// 55
-	&rig_TT563,		// 56
-	&rig_TT566,		// 57
-	&rig_TT588,		// 58
-	&rig_TT599,		// 59
+	&rig_FT900,		// 11
+	&rig_FT920,		// 12
+	&rig_FT950,		// 13
+	&rig_FT990,		// 14
+	&rig_FT990A,	// 15
+	&rig_FT991,		// 16
+	&rig_FT1000MP,	// 17
+	&rig_FT2000,	// 18
+	&rig_FTdx1200,	// 19
+	&rig_FTdx3000,	// 20
+	&rig_FT5000,	// 21
+	&rig_FTdx9000,	// 22
+	&rig_IC703,		// 23
+	&rig_IC706MKIIG,// 24
+	&rig_IC718,		// 25
+	&rig_IC728,		// 26
+	&rig_IC735,		// 27
+	&rig_IC746,		// 28
+	&rig_IC746PRO,	// 29
+	&rig_IC756,		// 30
+	&rig_IC756PRO,	// 31
+	&rig_IC756PRO2,	// 32
+	&rig_IC756PRO3,	// 33
+	&rig_IC7000,	// 34
+	&rig_IC7100,	// 35
+	&rig_IC7200,	// 36
+	&rig_IC7410,	// 37
+	&rig_IC7600,	// 38
+	&rig_IC7700,	// 39
+	&rig_IC7800,	// 40
+	&rig_IC9100,	// 41
+	&rig_IC910H,	// 42
+	&rig_K2,		// 43
+	&rig_K3,		// 44
+	&rig_KX3,		// 45
+	&rig_PCR1000,	// 46
+	&rig_RAY152,	// 47
+	&rig_TS140,		// 48
+	&rig_TS450S,	// 49
+	&rig_TS480HX,	// 50
+	&rig_TS480SAT,	// 51
+	&rig_TS570,		// 52
+	&rig_TS590S,	// 53
+	&rig_TS590SG,   // 54
+	&rig_TS870S,	// 55 wbx
+	&rig_TS990,		// 56
+	&rig_TS2000,	// 57
+	&rig_TT516,		// 58
+	&rig_TT535,		// 59
+	&rig_TT538,		// 60
+	&rig_TT550,		// 61
+	&rig_TT563,		// 62
+	&rig_TT566,		// 63
+	&rig_TT588,		// 64
+	&rig_TT599,		// 65
 	NULL
 };
 
