@@ -125,7 +125,7 @@ void debug::log(level_e level, const char* func, const char* srcf, int line, con
 	vsnprintf(sztemp, sizeof(sztemp), fmt, args);
 
 	estr.append(sztemp);
-printf("%s", sztemp);
+//printf("%s", sztemp);
 
 	fprintf(wfile, "%s", sztemp);
 
@@ -150,7 +150,7 @@ void debug::slog(level_e level, const char* func, const char* srcf, int line, co
 
 	vsnprintf(sztemp, sizeof(sztemp), fmt, args);
 	estr.append(sztemp);
-printf("%s\n", sztemp);
+//printf("%s\n", sztemp);
 
 	fprintf(wfile, "%s", sztemp);
 	va_end(args);
